@@ -1,18 +1,17 @@
 import logging
 import time
-import requests
 
 logger = logging.getLogger(__name__)
 
-import base64
 from typing import Any, Dict, List
 from urllib import parse
 
 import rumpy.utils as utils
+from rumpy.client import HttpRequest
 from rumpy.exceptions import *
-from rumpy.types.sign_trx import trx_decrypt, trx_encrypt
 from rumpy.types.data import *
 from rumpy.types.pack_trx import *
+from rumpy.types.sign_trx import trx_decrypt, trx_encrypt
 
 
 class MiniNode:
@@ -32,8 +31,10 @@ class MiniNode:
             jwt = jwt["jwt"][0]
         else:
             jwt = None
-        self.api_base = f"{url.scheme}://{url.netloc}/api/v1/node"
-        self.jwt = jwt
+
+        self.http = HttpRequest(
+            api_base=f"{url.scheme}://{url.netloc}/api/v1", jwt_token=jwt, is_session=False, is_connection=False
+        )
         self.group_id = info["group_id"]
         self.aes_key = bytes.fromhex(info["chiperkey"])
 
@@ -56,30 +57,6 @@ class MiniNode:
         obj = Mini.pack_like_obj(trx_id, like_type)
         return self.send_trx(private_key, obj, timestamp, seedurl)
 
-    def _post(self, endpoint="", payload=None):
-        headers = {
-            "USER-AGENT": "rumpy.api",
-            "Content-Type": "application/json",
-            "Connection": "close",
-        }
-        if self.jwt:
-            headers["Authorization"] = f"Bearer {self.jwt}"
-        url = f"{self.api_base}{endpoint}"
-        resp = requests.post(url, json=payload, headers=headers)
-
-        try:
-            resp_json = resp.json()
-        except Exception as e:
-            logger.warning(f"Exception {e}")
-            resp_json = {"error": str(e)}
-
-        if resp.status_code != 200:
-            logger.info(f"payload:{payload}")
-            logger.info(f"resp_json:{resp_json}")
-            logger.info(f"resp.status_code:{resp.status_code}")
-
-        return resp_json
-
     def send_trx(self, private_key, obj, timestamp=None, seedurl=None):
         """
         obj: dict,packed from rumpy.types.pack_trx
@@ -94,7 +71,14 @@ class MiniNode:
             timestamp = timestamp.replace("/", "-")[:16]
             timestamp = time.mktime(time.strptime(timestamp, "%Y-%m-%d %H:%M"))
         trx = trx_encrypt(self.group_id, self.aes_key, private_key, obj, timestamp)
-        return self._post(endpoint=f"/trx/{self.group_id}", payload=trx)
+        return self.http.post(endpoint=f"/node/trx/{self.group_id}", payload=trx)
+
+    def get_trx(self, trx_id):
+        return self.http.get(endpoint=f"/trx/{self.group_id}/{trx_id}")
 
     def encrypt_trx(self, encrypted_trx: dict):
         return trx_decrypt(self.aes_key, encrypted_trx)
+
+    def trx(self, trx_id):
+        encrypted_trx = self.get_trx(trx_id)
+        return self.encrypt_trx(encrypted_trx)
